import unittest

from kanina.calculator import *


class TestSum(unittest.TestCase):
    def test_sum(self):
        """
        Test that it can sum a list of integers
        """
        c = Calculator()
        data = [1, 2, 3]
        for num in data:
            c.add(num)
        result = c.cval()
        self.assertEqual(result, 6)

    def test_sub(self):
        """
        Test that it can subtract a list of integers
        """
        c = Calculator()
        data = [1, 2, 3]
        for num in data:
            c.sub(num)
        result = c.cval()
        self.assertEqual(result, -6)

    def test_reset(self):
        """
        Test that it sets to 0
        """
        c = Calculator()
        data = [1, 2, 3]
        for num in data:
            c.sub(num)
        c.reset()
        result = c.cval()
        self.assertEqual(result, 0)

    def test_mult(self):
        """
        Test that it multiplies correctly
        """
        c = Calculator(1)
        data = [1, 2, 3, -4]
        for num in data:
            c.mult(num)
        result = c.cval()
        self.assertEqual(result, -24)

    def test_div(self):
        """
        Test that it divides correctly
        """
        c = Calculator(100)
        data = [1, 2, 10]
        for num in data:
            c.div(num)
        result = c.cval()
        self.assertEqual(result, 5)

    def test_pow(self):
        """
        Test that raises by power correctly
        """
        c = Calculator(2)
        self.assertEqual(c.pow(3), 8)
        c = Calculator(-2)
        self.assertEqual(c.pow(5), -32)

    def test_1_cannot_add_int_and_str(self):
        """
        Test that ValueError is raised when trying to apply even root operation on negative number
        """
        with self.assertRaises(ValueError):
            c = Calculator(-16)
            c.root(4)

    def test_root(self):
        """
        Test that calculates root correctly
        """
        c = Calculator(16)
        self.assertEqual(c.root(2), 4.)
        c = Calculator(-27)
        self.assertEqual(c.root(3), -3.)

if __name__ == '__main__':
    unittest.main()





import math

class Calculator:
    """
    A simple calculator class with memory function
    """
    def __init__(self, value: float = 0):
        self.__value = value

    def reset(self):
        self.__value = 0

    def cval(self) -> float:
        return self.__value

    def add(self, num:float) -> float:
        self.__value = self.__value + num
        return self.__value

    def sub(self, num:float) -> float:
        self.__value = self.__value - num
        return self.__value

    def mult(self, num:float) -> float:
        self.__value = self.__value * num
        return self.__value

    def div(self, num:float) -> float:
        self.__value = self.__value / num
        return self.__value

    def pow(self, num:float) -> float:
        self.__value = self.__value ** num
        return self.__value

    def root(self, num:float) -> float:
        if self.__value < 0 and num % 2 == 0:
            raise ValueError('Math domain error')
        self.__value = math.pow(abs(self.__value), 1. / num) * (1, -1)[self.__value < 0]
        return self.__value



#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['kanina']

package_data = \
{'': ['*'], 'kanina': ['dist/*']}

setup(name='kanina',
      version='0.0.1',
      description='An simple calculator package',
      author='Henrikas',
      author_email='henrikass@yahoo.com',
      url=None,
      packages=packages,
      package_data=package_data,
      python_requires='>=3.8',
     )
